Performs the mathematical calculations taking bulk tumor data and deconvolved profiles and returning deconvolved tumour adjacent cell profiles.
ISOpure.calculate.tac(tumor.profiles, deconvolved.profiles, purity.estimates)a GxD matrix representing gene expression profiles of heterogeneous (mixed) tumor samples, where G is the number of genes, D is the number of tumor samples.
a GxD matrix representing gene expression profiles of purified (ISOpure output) tumor samples, where G is the number of genes, D is the number of tumor samples.
a vector D representing the purity estimates (output from ISOpure)
a GxD matrix representing gene expression profiles of purified (ISOpure output) tumor adjacent cell signal, where G is the number of genes, D is the number of tumor samples.