Arguments
tumordata
(same as for ISOpureS1) a GxD matrix representing gene expression profiles of
heterogeneous (mixed) tumor samples, where G is the number of genes, D is the number of tumor
samples.
BB
(same as for ISOpureS1) represents B = [b_1 ... b_(K-1)] matrix (from Genome Medicine
paper) a Gx(K-1) matrix, where (K-1) is the number of normal profiles
$(\beta_1,...,\beta_(K-1))$, G is the number of genes. These are the normal profiles
representing normal cells that contaminate the tumor samples (i.e. normal samples from the
same tissue location as the tumor). The minimum element of BB must be greater than 0 --
i.e. every gene/transcript must be observed on some level in each normal sample.
ISOpureS1model
output model list from ISOpureS1 code
MIN_KAPPA
(optional) The minimum value allowed for the strength parameter kappa placed
over the reference cancer profile m (see Quon et al, 2013). By default, this is set to
1/min(BB), such that the log likelihood of the model is always finite. However, when the
min(BB) is very small, this forces MIN_KAPPA to be very large, and can sometimes cause the
reference profile m to look too much like a 'normal profile' (and therefore you may observe
the tumor samples having low % cancer content estimates). If this is the case, you can try
setting MIN_KAPPA=1, or some other small value. For reference, for the data presented in
Quon et al., 2013, MIN_KAPPA is on the order of 10^5.
logging.level
(optional) A string that gives the logging threshold for futile.logger. The
possible options are 'TRACE', 'DEBUG', 'INFO', 'WARN', 'ERROR', 'FATAL'. Currently the
messages in ISOpureR are only in the categories 'INFO', 'WARN', and 'FATAL', and the default
setting is 'INFO'. Setting a setting for the entire package will over-ride the setting for
a particular function.