Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_core.new_model: Initialize a model list to hold all the parameters

Description

Produces a list (the model) which initializes the parameters vv, log_BBtranspose, PPtranspose, kappa, theta, omega, log_all_rates for step 1

Usage

ISOpureS1.model_core.new_model(tumordata, kappa, INITIAL_VV, PPtranspose, BBtranspose)

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumor samples
kappa
scalar strength parameter kappa placed over the reference cancer profile mm
INITIAL_VV
a vector with K components, the prior over mixing proportions, theta, with last entry weighed more heavily
PPtranspose
a (K-1)xG matrix, standardized so that all entries sum to 1, see ISOpure.step1.CPE.R
BBtranspose
a (K-1)xG matrix of the standardized normal profiles, so that they sum to 1

Value

model
a newly generated model list to hold all the parameters vv, log_BBtranspose, PPtranspose, kappa, theta, omega, log_all_rates