Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_core.optmodel: Optimizes the ISOpure parameters for step 1

Description

Optimizes the ISOpure parameters for step 1 cyclically until convergence

Usage

ISOpureS1.model_core.optmodel(tumordata, model, NUM_ITERATIONS=35)

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS
(optional) minimum number of iterations of optimization algorithm, default is 35

Value

model
updated model list containing all the parameters