Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_optimize.kappa.kappa_compute_loglikelihood: Compute loglikelihood relevant to kappa for step 1

Description

Computes the part of the loglikelihood function relevant to optimizing kappa for step 1

Usage

ISOpureS1.model_optimize.kappa.kappa_compute_loglikelihood(kappa, tumordata, model)

Arguments

kappa
a scalar kappa, the strength parameter in the prior over the reference cancer profile
tumordata
a GxD matrix representing gene expression profiles of tumour samples
model
list containing all the parameters to be optimized

Value