ISOpureS1.model_optimize.kappa.kappa_deriv_loglikelihood: Compute derivative of loglikelihood with respect to kappa for step 1
Description
Computes the derivative of the part of the loglikelihood function relevant to
optimizing kappa for step 1. Instead of performing constrained optimization on kappa directly,
we optimize the log of kappa in an unconstrained fashion. Thus, if y=log(kappa) and L is the
loglikelihood function w.r.t. y, to optimize L w.r.t. y, dL/dy = dL/dkappa * dkappa/dy,
where dkappa/dy = exp(y)= exp( log(kappa)). The input into the derivative function is
log(kappa - model\$MIN_KAPPA).