Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_optimize.omega.omega_compute_loglikelihood: Compute loglikelihood relevant to omega for step 1

Description

Computes the part of the loglikelihood function relevant to optimizing omega for step 1

Usage

ISOpureS1.model_optimize.omega.omega_compute_loglikelihood(omega, tumordata, model)

Arguments

omega
(K-1)x1 matrix representing the weights of the normal profiles B_i used to make the weighted combination that forms the mean parameter vector for the Dirichlet distribution over m
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized

Value