Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_optimize.omega.omega_deriv_loglikelihood: Compute the derivative of loglikelihood relevant to omega for step 1

Description

Compute the derivative of the part of the loglikelihood function relevant to omega with respect to (log) omega, in step 1. Instead of performing constrained optimization on omega directly, we optimize the log of omega in an unconstrained fashion.

Usage

ISOpureS1.model_optimize.omega.omega_deriv_loglikelihood(ww, tumordata, model)

Arguments

ww
(K-1)x1 matrix, log(omega), where the entries in omega are constrained to add to 1 where K-1 is the number of normal samples
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized

Value

with respect to (log) omega