Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS1.model_optimize.omega.omega_loglikelihood: Compute the loglikelihood relevant to omega for step 1
Description
Compute the the part of the loglikelihood function relevant to omega in step 1
Usage
ISOpureS1.model_optimize.omega.omega_loglikelihood(ww, tumordata, model)
Arguments
ww
(K-1)x1 matrix, log(omega), where the entries in omega are constrained to add to 1 where K-1 is the number of normal samples
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized
Value