Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_optimize.opt_mm: Optimize the reference cancer profile, m, in step 1

Description

The goal of this function is to optimize the reference cancer profile mm. Because mm is constrained (must be parameters of multinomial/discrete distribution), we don't directly optimize the likelihood function w.r.t. mm, but we perform change of variables to do unconstrained optimization. We therefore store these unconstrained variables in the field "mm_weights", and update these variables.

Usage

ISOpureS1.model_optimize.opt_mm( tumordata, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS )

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumour samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS_RMINIMIZE
minimum number of iteration that the minimization algorithm runs
iter
the iteration number
NUM_GRID_SEARCH_ITERATIONS
number of times to try restarting with different initial values

Value