Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS1.model_optimize.opt_omega: Optimize omega in step 1

Description

This function optimizes omega, in fact the convex mixing weights that govern prior over the reference cancer profile.

Usage

ISOpureS1.model_optimize.opt_omega( tumordata, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS )

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumour samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS_RMINIMIZE
minimum number of iteration that the minimization algorithm runs
iter
the iteration number
NUM_GRID_SEARCH_ITERATIONS
number of times to try restarting with different initial values

Value