ISOpureS1.model_optimize.theta.theta_deriv_loglikelihood: Compute the derivative of loglikelihood relevant to theta for step 1
Description
Computes the derivative of the loglikelihood function relevant to optimizing theta, not
with respect to theta but with respect to unconstrained variables