Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS1.model_optimize.vv.vv_compute_loglikelihood: Compute loglikelihood relevant to vv for step 1
Description
Computes the part of the loglikelihood function relevant to optimizing vv for step 1.
Usage
ISOpureS1.model_optimize.vv.vv_compute_loglikelihood(vv, sum_log_theta, DD)
Arguments
vv
Kx1 matrix representing the weights of the normal profiles B_i used to make the weighted combination that forms the mean parameter vector for the Dirichlet distribution over m
sum_log_theta
the column sums of log(theta), a 1xK matrix
DD
the number of patients (a scalar)
Value