Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS2.model_core.compute_loglikelihood: Compute loglikelihood given all model parameters for step 2
Description
Computes complete loglikelihood given all model parameters for step 2
Usage
ISOpureS2.model_core.compute_loglikelihood(tumordata, model)
Arguments
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters updated in ISOpure step two iterations
Value