Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS2.model_core.optmodel: Optimizes the ISOpure parameters for step 2
Description
Optimizes the ISOpure parameters for step 2 cyclically until convergence
Usage
ISOpureS2.model_core.optmodel(tumordata, model, NUM_ITERATIONS=35)
Arguments
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS
(optional) minimum number of iterations of optimization algorithm, default is 35
Value
model
updated model list containing all the parameters