Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS2.model_optimize.cc.cc_deriv_loglikelihood: Compute the derivative of loglikelihood relevant to the patient cancer profiles, cc, for step 2

Description

Computes the derivative of the part of the likelihood function relevant to optimizing cc.

Usage

ISOpureS2.model_optimize.cc.cc_deriv_loglikelihood(ww, tumordata, dd, model)

Arguments

ww
the cc_weights for patient dd, with G entries
tumordata
a GxD matrix representing gene expression profiles of tumor samples
dd
the patient number
model
list containing all the parameters to be optimized

Value

dd, the cancer profile for that patient. The derivative is taken not with respect to vv but with respect to unconstrained variables via a change of variables