ISOpureS2.model_optimize.kappa.kappa_deriv_loglikelihood: Compute derivative of loglikelihood with respect to kappa for step 2
Description
Computes the derivative of the part of the loglikelihood function relevant to
optimizing kappa for step 2. Instead of performing constrained optimization on kappa
directly, we optimize the log of kappa in an unconstrained fashion.