Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS2.model_optimize.opt_cc: Optimize the tumor-specific cancer profiles in step 2

Description

Optimize the tumor-specific cancer profiles. Because cc is constrained (each cc_i are parameters of multinomial/discrete distribution), we don't directly optimize the likelihood function w.r.t. cc, but we perform change of variables to do unconstrained optimization. We therefore store these unconstrained variables in the field "cc_weights", and update these variables.

Usage

ISOpureS2.model_optimize.opt_cc( tumordata, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS)

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumour samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS_RMINIMIZE
minimum number of iteration that the minimization algorithm runs
iter
the iteration number
NUM_GRID_SEARCH_ITERATIONS
number of times to try restarting with different initial values

Value