Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS2.model_optimize.opt_kappa: Optimize kappa in step 2

Description

This function optimizes kappa, the strength parameter in the prior over the reference cancer profile. Note that we don't directly optimize kappa because it has constraints (must be greater than the minimum determined in ISOpure.step2.PPE.)

Usage

ISOpureS2.model_optimize.opt_kappa( tumordata, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS )

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumour samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS_RMINIMIZE
minimum number of iteration that the minimization algorithm runs
iter
the iteration number
NUM_GRID_SEARCH_ITERATIONS
number of times to try restarting with different initial values

Value