Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS2.model_optimize.opt_vv: Optimize vv in step 2

Description

This function optimizes vv, the strength parameter in the prior over the reference cancer profile. Note that we don't directly optimize vv because it has constraints (must be >=1 to guarantee real-valued likelihoods).

Usage

ISOpureS2.model_optimize.opt_vv( tumordata, model, NUM_ITERATIONS_RMINIMIZE, iter, NUM_GRID_SEARCH_ITERATIONS )

Arguments

tumordata
a GxD matrix representing gene expression profiles of tumour samples
model
list containing all the parameters to be optimized
NUM_ITERATIONS_RMINIMIZE
minimum number of iteration that the minimization algorithm runs
iter
the iteration number
NUM_GRID_SEARCH_ITERATIONS
number of times to try restarting with different initial values

Value