Learn R Programming

ISOpureR (version 1.0.18)

ISOpureS2.model_optimize.theta.theta_deriv_loglikelihood: Compute the derivative of loglikelihood relevant to theta for step 2

Description

Computes the derivative of the loglikelihood function relevant to optimizing theta, not with respect to theta but with respect to unconstrained variables

Usage

ISOpureS2.model_optimize.theta.theta_deriv_loglikelihood(ww, tumordata, dd, model)

Arguments

ww
the theta weights corresponding to patient dd, a 1xK matrix
tumordata
a GxD matrix representing gene expression profiles of tumor samples
dd
the patient number
model
list containing all the parameters to be optimized

Value

with respect to theta but with respect to unconstrained variables.