Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpure.model_optimize.vv.vv_loglikelihood: Compute the loglikelihood relevant to vv for step 1
Description
Computes the part of the loglikelihood function relevant to optimizing vv for step 1
Usage
ISOpure.model_optimize.vv.vv_loglikelihood(ww, sum_log_theta, DD)
Arguments
ww
log(vv-1), a Kx1 matrix
sum_log_theta
the column sums of log(theta), a 1xK matrix
DD
the number of patients (a scalar)
Value