Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS1.model_optimize.mm.mm_loglikelihood: Compute the loglikelihood relevant to mm for step 1
Description
Computes the loglikelihood function relevant to optimizing the reference cancer profile, mm, for step 1
Usage
ISOpureS1.model_optimize.mm.mm_loglikelihood(ww, tumordata, model)
Arguments
ww
the mm_weights, with G entries
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized
Value