(K-1)x1 matrix representing the weights of the normal profiles B_i used to
make the weighted combination that forms the mean parameter vector for the
Dirichlet distribution over m
tumordata
a GxD matrix representing gene expression profiles of tumor samples
model
list containing all the parameters to be optimized