ISOpureS1.model_optimize.omega.omega_deriv_loglikelihood: Compute the derivative of loglikelihood relevant to omega for step 1
Description
Compute the derivative of the part of the loglikelihood function relevant to omega
with respect to (log) omega, in step 1. Instead of performing constrained optimization on omega
directly, we optimize the log of omega in an unconstrained fashion.