ISOpureS1.model_optimize.opt_mm: Optimize the reference cancer profile, m, in step 1
Description
The goal of this function is to optimize the reference cancer profile mm.
Because mm is constrained (must be parameters of multinomial/discrete
distribution), we don't directly optimize the likelihood function w.r.t.
mm, but we perform change of variables to do unconstrained
optimization. We therefore store these unconstrained variables in the
field "mm_weights", and update these variables.