a GxD matrix representing gene expression profiles of tumor samples
dd
the patient number
model
list containing all the parameters to be optimized
Value
dd, the cancer profile for that patient. The derivative is taken not with respect to vv but
with respect to unconstrained variables via a change of variables