Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS2.model_optimize.cc.cc_loglikelihood: Compute the loglikelihood relevant to the patient cancer profiles, cc, for step 2
Description
Computes the part of the loglikelihood function relevant to optimizing cc for patient dd, the cancer profile for that patient
Usage
ISOpureS2.model_optimize.cc.cc_loglikelihood(ww, tumordata, dd, model)
Arguments
ww
the cc_weights for patient dd, with G entries
tumordata
a GxD matrix representing gene expression profiles of tumor samples
dd
the patient number
model
list containing all the parameters to be optimized
Value
the cancer profile for that patient.