ISOpureS2.model_optimize.opt_vv: Optimize vv in step 2
Description
This function optimizes vv, the strength parameter in the prior over the reference
cancer profile. Note that we don't directly optimize vv because it has constraints (must be >=1
to guarantee real-valued likelihoods).