Rdocumentation
powered by
Learn R Programming
ISOpureR (version 1.0.18)
ISOpureS2.model_optimize.theta.theta_loglikelihood: Compute the loglikelihood relevant to theta for step 2
Description
Computes the part of the loglikelihood function relevant to optimizing theta for step 2
Usage
ISOpureS2.model_optimize.theta.theta_loglikelihood(ww, tumordata, dd, model)
Arguments
ww
the theta weights corresponding to patient dd, a 1xK matrix
tumordata
a GxD matrix representing gene expression profiles of tumor samples
dd
the patient number
model
list containing all the parameters to be optimized
Value